@@ -9,7 +9,7 @@ from telebot.runner import BotRunner
 logger = logging.getLogger(__name__)
 
 
-ROUTE_TEMPLATE = "/webhook/{subroute}/"
+WEBHOOK_ROUTE = "/webhook/{subroute}/"
 
 
 class WebhookApp:
@@ -20,7 +20,7 @@ class WebhookApp:
         self.aiohttp_app = web.Application()
 
         self.aiohttp_app.on_cleanup.append(self.cleanup)
-        self.aiohttp_app.router.add_post(ROUTE_TEMPLATE, self.webhook_handler)
+        self.aiohttp_app.router.add_post(WEBHOOK_ROUTE, self.webhook_handler)
 
     async def webhook_handler(self, request: web.Request):
         subroute = request.match_info.get("subroute")
@@ -39,20 +39,28 @@ class WebhookApp:
         finally:
             return web.Response()
 
-    async def add_bot_runner(self, runner: BotRunner):
+    async def add_bot_runner(self, runner: BotRunner) -> bool:
         subroute = runner.webhook_subroute()
         try:
             await runner.bot.delete_webhook()
-            await runner.bot.set_webhook(url=self.base_url + ROUTE_TEMPLATE.format(subroute=subroute))
-            logger.info(f"Webhook set for {runner.name:>30}: /{subroute}")
+            await runner.bot.set_webhook(url=self.base_url + WEBHOOK_ROUTE.format(subroute=subroute))
+            logger.info(f"Webhook set for {runner.bot_prefix}: /webhook/{subroute}")
         except Exception as e:
-            logger.error(f"Error setting up webhook for the bot {runner.name}, dropping it: {e}")
-            return
+            logger.exception(f"Error setting up webhook for the bot {runner.bot_prefix}, dropping it: {e}")
+            return False
+
+        for endpoint in runner.aux_endpoints:
+            self.aiohttp_app.router.add_route(
+                endpoint.method,
+                endpoint.route,
+                endpoint.handler,
+            )
+            logger.info(f"Aux endpoint created for {runner.bot_prefix}: {endpoint.route}")
 
         loop = asyncio.get_running_loop()
         for idx, coro in enumerate(runner.background_jobs):
             idx += 1  # 1-based numbering
-            task = loop.create_task(coro, name=f"{runner.name}-{idx}")
+            task = loop.create_task(coro, name=f"{runner.bot_prefix}-{idx}")
             self.background_tasks.add(task)
 
             def background_job_done(task: asyncio.Task):
@@ -60,9 +68,25 @@ class WebhookApp:
                 logger.info(f"Backgound job completed: {task}")
 
             task.add_done_callback(background_job_done)
-            logger.info(f"Background task created for {runner.name} ({idx}/{len(runner.background_jobs)})")
+            logger.info(f"Background task created for {runner.bot_prefix} ({idx}/{len(runner.background_jobs)})")
 
-        self.bot_runner_by_subroute[runner.webhook_subroute()] = runner
+        self.bot_runner_by_subroute[subroute] = runner
+        return True
+
+    async def remove_bot_runner(self, runner: BotRunner) -> bool:
+        """Warning: background jobs and aux endpoints added with the runner are not removed/cancelled"""
+        subroute = runner.webhook_subroute()
+        if subroute not in self.bot_runner_by_subroute:
+            return False
+        try:
+            await runner.bot.delete_webhook()
+            logger.info(f"Webhook removed for {runner.bot_prefix}; was /webhook/{subroute}")
+        except Exception as e:
+            logger.exception(f"Error deleting webhook for the bot {runner.bot_prefix}, keeping it")
+            return False
+
+        self.bot_runner_by_subroute.pop(subroute)
+        return True
 
     async def cleanup(self, _):
         logger.debug("Cleanup started")
